@@ -55,6 +55,8 @@ import nokogiri.internals.XmlDomParserContext;
 @JRubyClass(name = "Nokogiri::XML::Node")
 public class XmlNode extends RubyObject
 {
+  private static final long serialVersionUID = 1L;
+
   protected static final String TEXT_WRAPPER_NAME = "nokogiri_text_wrapper";
 
   /** The underlying Node object. */
@@ -598,22 +600,23 @@ public class XmlNode extends RubyObject
       hrefStr = rubyStringToString(href.convertToString());
     }
 
-    NokogiriNamespaceCache nsCache = NokogiriHelpers.getNamespaceCache(node);
-    XmlNamespace cachedNamespace = nsCache.get(prefixStr, hrefStr);
-    if (cachedNamespace != null) { return cachedNamespace; }
-
     Node namespaceOwner;
     if (node.getNodeType() == Node.ELEMENT_NODE) {
       namespaceOwner = node;
-      Element element = (Element) node;
       // adds namespace as node's attribute
       String qName = prefix.isNil() ? "xmlns" : "xmlns:" + prefixStr;
-      element.setAttributeNS("http://www.w3.org/2000/xmlns/", qName, hrefStr);
-    } else if (node.getNodeType() == Node.ATTRIBUTE_NODE) { namespaceOwner = ((Attr) node).getOwnerElement(); }
-    else { namespaceOwner = node.getParentNode(); }
-
-    XmlNamespace ns = XmlNamespace.createImpl(namespaceOwner, prefix, prefixStr, href, hrefStr);
+      ((Element)node).setAttributeNS("http://www.w3.org/2000/xmlns/", qName, hrefStr);
+    } else if (node.getNodeType() == Node.ATTRIBUTE_NODE) {
+      namespaceOwner = ((Attr) node).getOwnerElement();
+    } else {
+      namespaceOwner = node.getParentNode();
+    }
 
+    NokogiriNamespaceCache nsCache = NokogiriHelpers.getNamespaceCache(node);
+    XmlNamespace ns = nsCache.get(prefixStr, hrefStr);
+    if (ns == null) {
+      ns = XmlNamespace.createImpl(namespaceOwner, prefix, prefixStr, href, hrefStr);
+    }
     if (node != namespaceOwner) {
       node = NokogiriHelpers.renameNode(node, ns.getHref(), ns.getPrefix() + ':' + node.getLocalName());
     }
@@ -658,7 +661,7 @@ public class XmlNode extends RubyObject
     NamedNodeMap nodeMap = this.node.getAttributes();
 
     if (nodeMap == null) { return runtime.newEmptyArray(); }
-    RubyArray attr = runtime.newArray(nodeMap.getLength());
+    RubyArray<?> attr = runtime.newArray(nodeMap.getLength());
 
     final XmlDocument doc = document(context.runtime);
     for (int i = 0; i < nodeMap.getLength(); i++) {
@@ -759,14 +762,14 @@ public class XmlNode extends RubyObject
     if (children.getLength() == 0) {
       return Collections.emptyList();
     }
-    ArrayList<Node> elements = firstOnly ? null : new ArrayList<Node>(children.getLength());
+    ArrayList<Node> elements = new ArrayList<Node>();
     for (int i = 0; i < children.getLength(); i++) {
       Node child = children.item(i);
       if (child.getNodeType() == Node.ELEMENT_NODE) {
-        if (firstOnly) {
-          return Collections.singletonList(child);
-        }
         elements.add(child);
+        if (firstOnly) {
+          return elements;
+        }
       }
     }
     return elements;
@@ -848,8 +851,8 @@ public class XmlNode extends RubyObject
 
     XmlDocument doc = ctx.parse(context, klass, context.nil);
 
-    RubyArray documentErrors = getErrors(document);
-    RubyArray docErrors = getErrors(doc);
+    RubyArray<?> documentErrors = getErrors(document);
+    RubyArray<?> docErrors = getErrors(doc);
     if (checkNewErrors(documentErrors, docErrors)) {
       for (int i = 0; i < docErrors.getLength(); i++) {
         documentErrors.append(docErrors.entry(i));
@@ -871,7 +874,7 @@ public class XmlNode extends RubyObject
     return XmlNodeSet.newNodeSet(context.runtime, nodes, this);
   }
 
-  private static RubyArray
+  private static RubyArray<?>
   getErrors(XmlDocument document)
   {
     IRubyObject obj = document.getInstanceVariable("@errors");
@@ -880,7 +883,7 @@ public class XmlNode extends RubyObject
   }
 
   private static boolean
-  checkNewErrors(RubyArray baseErrors, RubyArray newErrors)
+  checkNewErrors(RubyArray<?> baseErrors, RubyArray<?> newErrors)
   {
     int length = ((RubyArray) newErrors.op_diff(baseErrors)).size();
     return length > 0;
@@ -1191,7 +1194,7 @@ public class XmlNode extends RubyObject
    * of this node.
    */
   @JRubyMethod
-  public IRubyObject
+  public RubyArray<?>
   namespace_definitions(ThreadContext context)
   {
     // don't use namespace_definitions cache anymore since
@@ -1203,7 +1206,19 @@ public class XmlNode extends RubyObject
     if (doc instanceof Html4Document) { return context.runtime.newEmptyArray(); }
 
     List<XmlNamespace> namespaces = doc.getNamespaceCache().get(node);
-    return context.runtime.newArray((List) namespaces);
+    return RubyArray.newArray(context.runtime, namespaces);
+
+    // // TODO: I think this implementation would be better but there are edge cases
+    // // See https://github.com/sparklemotion/nokogiri/issues/2543
+    // RubyArray<?> nsdefs = RubyArray.newArray(context.getRuntime());
+    // NamedNodeMap attrs = node.getAttributes();
+    // for (int j = 0 ; j < attrs.getLength() ; j++) {
+    //   Attr attr = (Attr)attrs.item(j);
+    //   if ("http://www.w3.org/2000/xmlns/" == attr.getNamespaceURI()) {
+    //     nsdefs.append(XmlNamespace.createFromAttr(context.getRuntime(), attr));
+    //   }
+    // }
+    // return nsdefs;
   }
 
   /**
@@ -1211,7 +1226,7 @@ public class XmlNode extends RubyObject
    * on any ancestor node.
    */
   @JRubyMethod
-  public RubyArray
+  public RubyArray<?>
   namespace_scopes(ThreadContext context)
   {
     final XmlDocument doc = document(context.runtime);
@@ -1228,7 +1243,7 @@ public class XmlNode extends RubyObject
     }
     if (previousNode == null) { return context.runtime.newEmptyArray(); }
 
-    final RubyArray scoped_namespaces = context.runtime.newArray();
+    final RubyArray<?> scoped_namespaces = context.runtime.newArray();
     final HashSet<String> prefixes_in_scope = new HashSet<String>(8);
     NokogiriNamespaceCache nsCache = NokogiriHelpers.getNamespaceCache(previousNode);
     for (Node previous = previousNode; previous != null;) {
@@ -1327,12 +1342,21 @@ public class XmlNode extends RubyObject
     IRubyObject io = args[0];
     IRubyObject encoding = args[1];
     IRubyObject indentString = args[2];
-    IRubyObject options = args[3];
+    IRubyObject options_rb = args[3];
+    int options = RubyFixnum.fix2int(options_rb);
 
     String encString = rubyStringToString(encoding);
 
+    // similar to behavior of libxml2's xmlSaveTree function
+    if ((options & SaveContextVisitor.AS_XML) == 0 &&
+        (options & SaveContextVisitor.AS_XHTML) == 0 &&
+        (options & SaveContextVisitor.AS_HTML) == 0 &&
+        isHtmlDoc(context)) {
+      options |= SaveContextVisitor.DEFAULT_HTML;
+    }
+
     SaveContextVisitor visitor =
-      new SaveContextVisitor(RubyFixnum.fix2int(options), rubyStringToString(indentString), encString, isHtmlDoc(context),
+      new SaveContextVisitor(options, rubyStringToString(indentString), encString, isHtmlDoc(context),
                              isFragment(), 0);
     accept(context, visitor);
 
@@ -1438,7 +1462,7 @@ public class XmlNode extends RubyObject
     XmlNode currentNode = this;
     final XmlDocument doc = document(context.runtime);
     while (currentNode != doc) {
-      RubyArray namespaces = currentNode.namespace_scopes(context);
+      RubyArray<?> namespaces = currentNode.namespace_scopes(context);
       for (int i = 0; i < namespaces.size(); i++) {
         XmlNamespace namespace = (XmlNamespace) namespaces.eltInternal(i);
         if (namespace.hasPrefix(prefix)) { return namespace.getHref(); }
@@ -1891,7 +1915,7 @@ public class XmlNode extends RubyObject
   process_xincludes(ThreadContext context, IRubyObject options)
   {
     XmlDocument xmlDocument = (XmlDocument)document(context);
-    RubyArray errors = (RubyArray)xmlDocument.getInstanceVariable("@errors");
+    RubyArray<?> errors = (RubyArray)xmlDocument.getInstanceVariable("@errors");
     while (errors.getLength() > 0) {
       XmlSyntaxError error = (XmlSyntaxError)errors.shift(context);
       if (error.toString().contains("Include operation failed")) {
@@ -1911,11 +1935,11 @@ public class XmlNode extends RubyObject
 
   @SuppressWarnings("unchecked")
   @Override
-  public Object
-  toJava(final Class target)
+  public <T> T
+  toJava(Class<T> target)
   {
     if (target == Object.class || Node.class.isAssignableFrom(target)) {
-      return getNode();
+      return (T)getNode();
     }
     return super.toJava(target);
   }
