@@ -57,6 +57,7 @@ import nokogiri.internals.ReaderNode.TextNode;
 @JRubyClass(name = "Nokogiri::XML::Reader")
 public class XmlReader extends RubyObject
 {
+  private static final long serialVersionUID = 1L;
 
   private static final int XML_TEXTREADER_MODE_INITIAL = 0;
   private static final int XML_TEXTREADER_MODE_INTERACTIVE = 1;
@@ -141,9 +142,17 @@ public class XmlReader extends RubyObject
   public IRubyObject
   attribute_nodes(ThreadContext context)
   {
+    context.runtime.getWarnings().warn("Reader#attribute_nodes is deprecated and will be removed in a future version of Nokogiri. Please use Reader#attribute_hash instead.");
     return currentNode().getAttributesNodes();
   }
 
+  @JRubyMethod
+  public IRubyObject
+  attribute_hash(ThreadContext context)
+  {
+    return currentNode().getAttributes(context);
+  }
+
   @JRubyMethod(name = "attributes?")
   public IRubyObject
   attributes_p(ThreadContext context)
@@ -216,7 +225,7 @@ public class XmlReader extends RubyObject
 
     Options options;
     if (args.length > 3) {
-      options = new ParserContext.Options((Long)args[3].toJava(Long.class));
+      options = new ParserContext.Options(args[3].toJava(Long.class));
     } else {
       // use the default options RECOVER | NONET
       options = new ParserContext.Options(2048 | 1);
@@ -247,7 +256,7 @@ public class XmlReader extends RubyObject
 
     Options options;
     if (args.length > 3) {
-      options = new ParserContext.Options((Long)args[3].toJava(Long.class));
+      options = new ParserContext.Options(args[3].toJava(Long.class));
     } else {
       // use the default options RECOVER | NONET
       options = new ParserContext.Options(2048 | 1);
@@ -395,7 +404,7 @@ public class XmlReader extends RubyObject
     final ReaderNode currentNode = currentNode();
     if (currentNode == null) { return runtime.getNil(); }
     if (currentNode.isError()) {
-      RubyArray errors = (RubyArray) getInstanceVariable("@errors");
+      RubyArray<?> errors = (RubyArray) getInstanceVariable("@errors");
       IRubyObject error = currentNode.toSyntaxError();
       errors.append(error);
       setInstanceVariable("@errors", errors);
