@@ -16,6 +16,7 @@
 require "simplecov"
 SimpleCov.start do
   add_filter "/test/"
+  enable_coverage :branch
 end
 
 $VERBOSE = true
@@ -127,7 +128,7 @@ module Nokogiri
   end
 
   # rubocop:disable Style/ClassVars
-  class TestCase < MiniTest::Spec
+  class TestCase < Minitest::Spec
     include TestBase
 
     COMPACT_EVERY = 20
@@ -197,7 +198,7 @@ module Nokogiri
         when "verify"
           if @@test_count % COMPACT_EVERY == 0
             # https://alanwu.space/post/check-compaction/
-            GC.verify_compaction_references(double_heap: true, toward: :empty)
+            gc_verify_compaction_references
           end
           GC.start(full_mark: true)
         when "stress"
@@ -212,6 +213,14 @@ module Nokogiri
       super
     end
 
+    def gc_verify_compaction_references
+      if Gem::Requirement.new(">= 3.2.0").satisfied_by?(Gem::Version.new(RUBY_VERSION))
+        GC.verify_compaction_references(expand_heap: true, toward: :empty)
+      else
+        GC.verify_compaction_references(double_heap: true, toward: :empty)
+      end
+    end
+
     def stress_memory_while(&block)
       # force the test to explicitly declare a skip
       raise "memory stress tests shouldn't be run on JRuby" if Nokogiri.jruby?
@@ -263,7 +272,7 @@ module Nokogiri
     def pending(msg)
       begin
         yield
-      rescue MiniTest::Assertion
+      rescue Minitest::Assertion
         skip("pending #{msg} [#{caller(2..2).first}]")
       end
       flunk("pending test unexpectedly passed: #{msg} [#{caller(1..1).first}]")
@@ -378,12 +387,18 @@ module Nokogiri
 
         [
           :xmldecl,
-          :start_document, :end_document,
-          :start_element, :end_element,
-          :start_element_namespace, :end_element_namespace,
-          :characters, :comment, :cdata_block,
+          :start_document,
+          :end_document,
+          :start_element,
+          :end_element,
+          :start_element_namespace,
+          :end_element_namespace,
+          :characters,
+          :comment,
+          :cdata_block,
           :processing_instruction,
-          :error, :warning,
+          :error,
+          :warning,
         ].each do |name|
           define_method name do |*arguments|
             @items << [name, *arguments]
