@@ -755,6 +755,29 @@ module Nokogiri
           assert_equal(expected, doc.at_css("body").children.map(&:type))
         end
 
+        it "emits HTML even when no save options are specified" do
+          doc = Nokogiri::HTML4::Document.parse("<html><body><div>hello</div></body></html>")
+          expected = doc.to_html
+
+          assert_equal(
+            expected,
+            doc.write_to(StringIO.new, save_with: Nokogiri::XML::Node::SaveOptions::DEFAULT_HTML).tap(&:rewind).read,
+          )
+          assert_equal(
+            expected,
+            doc.write_to(StringIO.new).tap(&:rewind).read,
+          )
+
+          # but not when the AS_XML or AS_XHTML flag is set
+          as_xml = doc.write_to(StringIO.new, save_with: Nokogiri::XML::Node::SaveOptions::AS_XML).tap(&:rewind).read
+          refute_equal(expected, as_xml)
+          assert(as_xml.start_with?("<?xml"))
+
+          as_xhtml = doc.write_to(StringIO.new, save_with: Nokogiri::XML::Node::SaveOptions::AS_XHTML).tap(&:rewind).read
+          refute_equal(expected, as_xhtml)
+          assert(as_xhtml.start_with?("<?xml"))
+        end
+
         describe ".parse" do
           let(:html_strict) do
             Nokogiri::XML::ParseOptions.new(Nokogiri::XML::ParseOptions::DEFAULT_HTML).norecover
