@@ -183,11 +183,15 @@ module Nokogiri
         if RUBY_PLATFORM.include?("java")
           # NKF linebreak modes are not supported as of jruby 1.2
           # see http://jira.codehaus.org/browse/JRUBY-3602 for status
-          assert_equal("<p>testparagraph\nfoobar</p>",
-            nokogiri.at("p").to_html.delete(" "))
+          assert_equal(
+            "<p>testparagraph\nfoobar</p>",
+            nokogiri.at("p").to_html.delete(" "),
+          )
         else
-          assert_equal("<p>testparagraph\r\nfoobar</p>",
-            nokogiri.at("p").to_html.delete(" "))
+          assert_equal(
+            "<p>testparagraph\r\nfoobar</p>",
+            nokogiri.at("p").to_html.delete(" "),
+          )
         end
       end
 
