@@ -50,8 +50,10 @@ module Nokogiri
       end
 
       def test_builder_nondefault_attr_ns
-        assert_equal("http://www.w3.org/1999/xlink",
-          check_namespace(@doc.root.elements[2].elements[0].attribute_nodes.find { |a| a.name.include?("href") }))
+        assert_equal(
+          "http://www.w3.org/1999/xlink",
+          check_namespace(@doc.root.elements[2].elements[0].attribute_nodes.find { |a| a.name.include?("href") }),
+        )
       end
 
       def test_builder_single_decl_ns_2
