@@ -81,7 +81,7 @@ module Nokogiri
         end
 
         def test_document_with_initial_space
-          doc = Nokogiri::XML(" <?xml version='1.0' encoding='utf-8' ?><first \>")
+          doc = Nokogiri::XML(" <?xml version='1.0' encoding='utf-8' ?><first >")
           assert_equal(2, doc.children.size)
         end
 
@@ -144,8 +144,10 @@ module Nokogiri
               </foo>
             </xml>
           eoxml
-          assert_equal({ "xmlns" => "hello", "xmlns:foo" => "world" },
-            doc.collect_namespaces)
+          assert_equal(
+            { "xmlns" => "hello", "xmlns:foo" => "world" },
+            doc.collect_namespaces,
+          )
         end
 
         def test_subclass_initialize_modify # testing a segv
@@ -250,7 +252,7 @@ module Nokogiri
         end
 
         def test_pp
-          out = StringIO.new((+""))
+          out = StringIO.new(+"")
           ::PP.pp(xml, out)
           assert_operator(out.string.length, :>, 0)
         end
@@ -491,33 +493,17 @@ module Nokogiri
           assert_equal(xml.root.to_s, xml.root.to_s)
         end
 
-        def test_encoding=
-          xml.encoding = "UTF-8"
-          assert_match("UTF-8", xml.to_xml)
-
-          xml.encoding = "EUC-JP"
-          assert_match("EUC-JP", xml.to_xml)
-        end
-
         def test_namespace_should_not_exist
           assert_raises(NoMethodError) do
             xml.namespace
           end
         end
 
-        def test_non_existant_function
-          # WTF.  I don't know why this is different between MRI and Jruby
-          # They should be the same...  Either way, raising an exception
-          # is the correct thing to do.
-          exception = RuntimeError
-
-          if !Nokogiri.uses_libxml? || (Nokogiri.uses_libxml? && Nokogiri::VERSION_INFO["libxml"]["platform"] == "jruby")
-            exception = Nokogiri::XML::XPath::SyntaxError
-          end
-
-          assert_raises(exception) do
+        def test_non_existent_function
+          e = assert_raises(Nokogiri::XML::XPath::SyntaxError) do
             xml.xpath("//name[foo()]")
           end
+          assert_match(/function.*not found|Could not find function/, e.to_s)
         end
 
         def test_xpath_syntax_error
@@ -704,8 +690,10 @@ module Nokogiri
           doc = Nokogiri::XML.parse(Pathname.new(XML_ATOM_FILE))
 
           # an arbitrary assertion on the structure of the document
-          assert_equal(20, doc.xpath("/xmlns:feed/xmlns:entry/xmlns:author",
-            "xmlns" => "http://www.w3.org/2005/Atom").length)
+          assert_equal(20, doc.xpath(
+            "/xmlns:feed/xmlns:entry/xmlns:author",
+            "xmlns" => "http://www.w3.org/2005/Atom",
+          ).length)
           assert_equal(XML_ATOM_FILE, doc.url)
         end
 
