@@ -16,6 +16,11 @@ module Nokogiri
           assert_predicate(node, :element?, "node is an element")
         end
 
+        def test_first_element_child_with_no_match
+          doc = Nokogiri::XML::Document.parse("<root>asdf</root>")
+          assert_nil(doc.root.first_element_child)
+        end
+
         def test_element_children
           nodes = xml.root.element_children
           assert_equal(xml.root.first_element_child, nodes.first)
@@ -27,6 +32,11 @@ module Nokogiri
           assert_equal(nodes.last, xml.root.element_children.last)
         end
 
+        def test_last_element_child_with_no_match
+          doc = Nokogiri::XML::Document.parse("<root>asdf</root>")
+          assert_nil(doc.root.last_element_child)
+        end
+
         def test_bad_xpath
           bad_xpath = "//foo["
 
@@ -753,8 +763,10 @@ module Nokogiri
         def test_ancestors
           address = xml.xpath("//address").first
           assert_equal(3, address.ancestors.length)
-          assert_equal(["employee", "staff", "document"],
-            address.ancestors.map(&:name))
+          assert_equal(
+            ["employee", "staff", "document"],
+            address.ancestors.map(&:name),
+          )
         end
 
         def test_read_only?
@@ -1072,32 +1084,57 @@ module Nokogiri
           XML
 
           namespaces = xml.namespaces # Document#namespace
-          assert_equal({ "xmlns" => "http://quux.com/",
-                         "xmlns:a" => "http://foo.com/",
-                         "xmlns:b" => "http://bar.com/", }, namespaces)
+          assert_equal(
+            {
+              "xmlns" => "http://quux.com/",
+              "xmlns:a" => "http://foo.com/",
+              "xmlns:b" => "http://bar.com/",
+            },
+            namespaces,
+          )
 
           namespaces = xml.root.namespaces
-          assert_equal({ "xmlns" => "http://quux.com/",
-                         "xmlns:a" => "http://foo.com/",
-                         "xmlns:b" => "http://bar.com/", }, namespaces)
+          assert_equal(
+            {
+              "xmlns" => "http://quux.com/",
+              "xmlns:a" => "http://foo.com/",
+              "xmlns:b" => "http://bar.com/",
+            },
+            namespaces,
+          )
 
           namespaces = xml.at_xpath("//xmlns:y").namespaces
-          assert_equal({ "xmlns" => "http://quux.com/",
-                         "xmlns:a" => "http://foo.com/",
-                         "xmlns:b" => "http://bar.com/",
-                         "xmlns:c" => "http://bazz.com/", }, namespaces)
+          assert_equal(
+            {
+              "xmlns" => "http://quux.com/",
+              "xmlns:a" => "http://foo.com/",
+              "xmlns:b" => "http://bar.com/",
+              "xmlns:c" => "http://bazz.com/",
+            },
+            namespaces,
+          )
 
           namespaces = xml.at_xpath("//xmlns:z").namespaces
-          assert_equal({ "xmlns" => "http://quux.com/",
-                         "xmlns:a" => "http://foo.com/",
-                         "xmlns:b" => "http://bar.com/",
-                         "xmlns:c" => "http://bazz.com/", }, namespaces)
+          assert_equal(
+            {
+              "xmlns" => "http://quux.com/",
+              "xmlns:a" => "http://foo.com/",
+              "xmlns:b" => "http://bar.com/",
+              "xmlns:c" => "http://bazz.com/",
+            },
+            namespaces,
+          )
 
           namespaces = xml.at_xpath("//xmlns:a").namespaces
-          assert_equal({ "xmlns" => "http://quux.com/",
-                         "xmlns:a" => "http://foo.com/",
-                         "xmlns:b" => "http://bar.com/",
-                         "xmlns:c" => "http://newc.com/", }, namespaces)
+          assert_equal(
+            {
+              "xmlns" => "http://quux.com/",
+              "xmlns:a" => "http://foo.com/",
+              "xmlns:b" => "http://bar.com/",
+              "xmlns:c" => "http://newc.com/",
+            },
+            namespaces,
+          )
         end
 
         def test_namespace
