@@ -17,7 +17,7 @@ module Nokogiri
 
       def test_new
         assert(schema = Nokogiri::XML::RelaxNG.new(
-          File.read(ADDRESS_SCHEMA_FILE)
+          File.read(ADDRESS_SCHEMA_FILE),
         ))
         assert_instance_of(Nokogiri::XML::RelaxNG, schema)
       end
@@ -50,8 +50,10 @@ module Nokogiri
         schema = Nokogiri::XML::RelaxNG.from_document(Nokogiri::XML::Document.parse(File.read(ADDRESS_SCHEMA_FILE)))
         assert_equal(Nokogiri::XML::ParseOptions::DEFAULT_SCHEMA, schema.parse_options)
 
-        schema = Nokogiri::XML::RelaxNG.from_document(Nokogiri::XML::Document.parse(File.read(ADDRESS_SCHEMA_FILE)),
-          Nokogiri::XML::ParseOptions.new.recover)
+        schema = Nokogiri::XML::RelaxNG.from_document(
+          Nokogiri::XML::Document.parse(File.read(ADDRESS_SCHEMA_FILE)),
+          Nokogiri::XML::ParseOptions.new.recover,
+        )
         assert_equal(Nokogiri::XML::ParseOptions.new.recover, schema.parse_options)
       end
 
@@ -62,8 +64,10 @@ module Nokogiri
         schema = Nokogiri::XML::RelaxNG.read_memory(File.read(ADDRESS_SCHEMA_FILE))
         assert_equal(Nokogiri::XML::ParseOptions::DEFAULT_SCHEMA, schema.parse_options)
 
-        schema = Nokogiri::XML::RelaxNG.read_memory(File.read(ADDRESS_SCHEMA_FILE),
-          Nokogiri::XML::ParseOptions.new.recover)
+        schema = Nokogiri::XML::RelaxNG.read_memory(
+          File.read(ADDRESS_SCHEMA_FILE),
+          Nokogiri::XML::ParseOptions.new.recover,
+        )
         assert_equal(Nokogiri::XML::ParseOptions.new.recover, schema.parse_options)
       end
 
